@@ -135,7 +135,7 @@ static void toggleSearch(EvBrowserPluginToolbar *toolbar)
 {
         if (!toolbar->priv->searchPopover) {
                 toolbar->priv->searchPopover = gtk_popover_new(toolbar->priv->searchToggleButton);
-		gtk_popover_set_position (GTK_POPOVER (toolbar->priv->searchPopover), GTK_POS_BOTTOM);
+                gtk_popover_set_position (GTK_POPOVER (toolbar->priv->searchPopover), GTK_POS_BOTTOM);
                 g_signal_connect_swapped(toolbar->priv->searchPopover, "closed", G_CALLBACK(searchPopoverClosed), toolbar);
                 GtkWidget *searchBox = ev_search_box_new(toolbar->priv->plugin->model());
                 g_signal_connect_swapped(searchBox, "started", G_CALLBACK(searchStarted), toolbar);
@@ -456,11 +456,23 @@ static void evBrowserPluginToolbarConstructed(GObject *object)
         gtk_widget_show(toolItem);
 }
 
+static void evBrowserPluginToolbarDispose(GObject *object)
+{
+        EvBrowserPluginToolbar *toolbar = EV_BROWSER_PLUGIN_TOOLBAR(object);
+        if (toolbar->priv->searchPopover) {
+                gtk_widget_destroy(toolbar->priv->searchPopover);
+                toolbar->priv->searchPopover = nullptr;
+        }
+
+        G_OBJECT_CLASS(ev_browser_plugin_toolbar_parent_class)->dispose(object);
+}
+
 static void ev_browser_plugin_toolbar_class_init(EvBrowserPluginToolbarClass *klass)
 {
         GObjectClass *gObjectClass = G_OBJECT_CLASS(klass);
         gObjectClass->set_property = evBrowserPluginToolbarSetProperty;
         gObjectClass->constructed = evBrowserPluginToolbarConstructed;
+        gObjectClass->dispose = evBrowserPluginToolbarDispose;
 
         g_object_class_install_property(gObjectClass,
                                          PROP_PLUGIN,
